@@ -5,11 +5,11 @@
 //           This file provides an SIMD version of the functions.
 // Language: C
 // Date:     24-Mar-2019
-// Ver:      27-Mar-2020.
+// Ver:      31-Oct-2021.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2020    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2021    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -28,7 +28,11 @@
 
 void degrees_float_1_simd(Py_ssize_t arraylen, float *data);
 void degrees_float_2_simd(Py_ssize_t arraylen, float *data, float *dataout);
+char degrees_float_1_simd_ovfl(Py_ssize_t arraylen, float *data);
+char degrees_float_2_simd_ovfl(Py_ssize_t arraylen, float *data, float *dataout);
 void degrees_double_1_simd(Py_ssize_t arraylen, double *data);
 void degrees_double_2_simd(Py_ssize_t arraylen, double *data, double *dataout);
+char degrees_double_1_simd_ovfl(Py_ssize_t arraylen, double *data);
+char degrees_double_2_simd_ovfl(Py_ssize_t arraylen, double *data, double *dataout);
 
 
